==> neo4j-schema-4.4.19-sources.jar: org/neo4j/internal/schema/constraints/IndexBackedConstraintDescriptor.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.schema.constraints;

import org.neo4j.internal.schema.ConstraintDescriptor;
import org.neo4j.internal.schema.IndexType;

public interface IndexBackedConstraintDescriptor extends ConstraintDescriptor
{
    /**
     * @return {@code true} if this constraint has a backing index, and calling {@link #ownedIndexId()} will not throw.
     */
    boolean hasOwnedIndexId();

    /**
     * Return the id of the index that is owned by this constraint, if any, or throw an {@link IllegalStateException}.
     * @return the id of the index backing this constraint.
     */
    long ownedIndexId();

    /**
     * Return the type of the index that is owned by this constraint, if any, or throw an {@link IllegalStateException}.
     * @return the type of the index backing this constraint.
     */
    IndexType indexType();
}

==> neo4j-schema-5.3.0-sources.jar: org/neo4j/internal/schema/constraints/IndexBackedConstraintDescriptor.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.schema.constraints;

import org.neo4j.internal.schema.ConstraintDescriptor;
import org.neo4j.internal.schema.IndexType;

public interface IndexBackedConstraintDescriptor extends ConstraintDescriptor {
    /**
     * @return {@code true} if this constraint has a backing index, and calling {@link #ownedIndexId()} will not throw.
     */
    boolean hasOwnedIndexId();

    /**
     * Return the id of the index that is owned by this constraint, if any, or throw an {@link IllegalStateException}.
     * @return the id of the index backing this constraint.
     */
    long ownedIndexId();

    /**
     * Return the type of the index that is owned by this constraint, if any, or throw an {@link IllegalStateException}.
     * @return the type of the index backing this constraint.
     */
    IndexType indexType();
}
